summaryrefslogtreecommitdiffstats
path: root/host/include
diff options
context:
space:
mode:
Diffstat (limited to 'host/include')
-rw-r--r--host/include/uhd/CMakeLists.txt1
-rw-r--r--host/include/uhd/usrp/CMakeLists.txt5
-rw-r--r--host/include/uhd/usrp/simple_usrp.hpp (renamed from host/include/uhd/simple_device.hpp)18
-rw-r--r--host/include/uhd/usrp/tune_helper.hpp (renamed from host/include/uhd/utils/tune_helper.hpp)10
-rw-r--r--host/include/uhd/utils/CMakeLists.txt1
-rw-r--r--host/include/uhd/utils/props.hpp6
6 files changed, 22 insertions, 19 deletions
diff --git a/host/include/uhd/CMakeLists.txt b/host/include/uhd/CMakeLists.txt
index 1c5202caa..d63062032 100644
--- a/host/include/uhd/CMakeLists.txt
+++ b/host/include/uhd/CMakeLists.txt
@@ -24,7 +24,6 @@ ADD_SUBDIRECTORY(utils)
INSTALL(FILES
config.hpp
device.hpp
- simple_device.hpp
wax.hpp
DESTINATION ${INCLUDE_DIR}/uhd
)
diff --git a/host/include/uhd/usrp/CMakeLists.txt b/host/include/uhd/usrp/CMakeLists.txt
index d0f385f13..7815a4fb9 100644
--- a/host/include/uhd/usrp/CMakeLists.txt
+++ b/host/include/uhd/usrp/CMakeLists.txt
@@ -33,5 +33,10 @@ INSTALL(FILES
### usrp headers ###
usrp1e.hpp
usrp2.hpp
+
+ ### utilities ###
+ tune_helper.hpp
+ simple_usrp.hpp
+
DESTINATION ${INCLUDE_DIR}/uhd/usrp
)
diff --git a/host/include/uhd/utils/tune_helper.hpp b/host/include/uhd/usrp/tune_helper.hpp
index 958d1eceb..f1e276d4f 100644
--- a/host/include/uhd/utils/tune_helper.hpp
+++ b/host/include/uhd/usrp/tune_helper.hpp
@@ -15,14 +15,14 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//
-#ifndef INCLUDED_UHD_UTILS_TUNE_HELPER_HPP
-#define INCLUDED_UHD_UTILS_TUNE_HELPER_HPP
+#ifndef INCLUDED_UHD_USRP_TUNE_HELPER_HPP
+#define INCLUDED_UHD_USRP_TUNE_HELPER_HPP
#include <uhd/config.hpp>
#include <uhd/wax.hpp>
#include <uhd/types/tune_result.hpp>
-namespace uhd{
+namespace uhd{ namespace usrp{
/*!
* Tune a rx chain to the desired frequency:
@@ -74,6 +74,6 @@ UHD_API tune_result_t tune_tx_subdev_and_duc(
wax::obj subdev, wax::obj duc, double target_freq
);
-} //namespace uhd
+}}
-#endif /* INCLUDED_UHD_UTILS_TUNE_HELPER_HPP */
+#endif /* INCLUDED_UHD_USRP_TUNE_HELPER_HPP */
diff --git a/host/include/uhd/utils/CMakeLists.txt b/host/include/uhd/utils/CMakeLists.txt
index 2bb72e31d..2831ab0b0 100644
--- a/host/include/uhd/utils/CMakeLists.txt
+++ b/host/include/uhd/utils/CMakeLists.txt
@@ -22,6 +22,5 @@ INSTALL(FILES
props.hpp
safe_main.hpp
static.hpp
- tune_helper.hpp
DESTINATION ${INCLUDE_DIR}/uhd/utils
)
diff --git a/host/include/uhd/utils/props.hpp b/host/include/uhd/utils/props.hpp
index fdbc17d1c..6be0b2ce5 100644
--- a/host/include/uhd/utils/props.hpp
+++ b/host/include/uhd/utils/props.hpp
@@ -15,8 +15,8 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//
-#ifndef INCLUDED_UHD_USRP_PROPS_COMMON_HPP
-#define INCLUDED_UHD_USRP_PROPS_COMMON_HPP
+#ifndef INCLUDED_UHD_UTILS_PROPS_HPP
+#define INCLUDED_UHD_UTILS_PROPS_HPP
#include <uhd/config.hpp>
#include <uhd/wax.hpp>
@@ -45,4 +45,4 @@ namespace uhd{
} //namespace uhd
-#endif /* INCLUDED_UHD_USRP_PROPS_COMMON_HPP */
+#endif /* INCLUDED_UHD_UTILS_PROPS_HPP */
diff --git a/host/include/uhd/simple_device.hpp b/host/include/uhd/usrp/simple_usrp.hpp
index 52928367a..dea1cabda 100644
--- a/host/include/uhd/simple_device.hpp
+++ b/host/include/uhd/usrp/simple_usrp.hpp
@@ -15,8 +15,8 @@
// along with this program. If not, see <http://www.gnu.org/licenses/>.
//
-#ifndef INCLUDED_UHD_SIMPLE_DEVICE_HPP
-#define INCLUDED_UHD_SIMPLE_DEVICE_HPP
+#ifndef INCLUDED_UHD_USRP_SIMPLE_USRP_HPP
+#define INCLUDED_UHD_USRP_SIMPLE_USRP_HPP
#include <uhd/config.hpp>
#include <uhd/device.hpp>
@@ -27,17 +27,17 @@
#include <boost/utility.hpp>
#include <vector>
-namespace uhd{
+namespace uhd{ namespace usrp{
/*!
* The simple UHD device class:
* A simple device facilitates ease-of-use for most use-case scenarios.
* The wrapper provides convenience functions to tune the devices
* as well as to set the dboard gains, antennas, and other properties.
*/
-class UHD_API simple_device : boost::noncopyable{
+class UHD_API simple_usrp : boost::noncopyable{
public:
- typedef boost::shared_ptr<simple_device> sptr;
+ typedef boost::shared_ptr<simple_usrp> sptr;
static sptr make(const std::string &args);
virtual device::sptr get_device(void) = 0;
@@ -92,6 +92,6 @@ public:
virtual std::vector<std::string> get_tx_antennas(void) = 0;
};
-} //namespace uhd
+}}
-#endif /* INCLUDED_UHD_SIMPLE_DEVICE_HPP */
+#endif /* INCLUDED_UHD_USRP_SIMPLE_USRP_HPP */
@@ -27,17 +27,17 @@
/*!
- * The simple UHD device class:
- * A simple device facilitates ease-of-use for most use-case scenarios.
+ * The simple USRP device class:
+ * A simple usrp facilitates ease-of-use for most use-case scenarios.
* The wrapper provides convenience functions to tune the devices
* as well as to set the dboard gains, antennas, and other properties.